# Copyright (C) 2021-2022 MicroSys Electronics GmbH
# Author: Kay Potthoff <kay.potthoff@microsys.de>

#LIC_FILES_CHKSUM = "file://COPYING;md5=6bc538ed5bd9a7fc9398086aedcd7e46"

FILESEXTRAPATHS:prepend := "${THISDIR}/${PN}:"
PATCHTOOL = "git"

SRCREV = "95448dd0dc9b621ae027cbefedaaa7c3d0d3ad2d"

KERNEL_IMAGETYPE += "Image.gz"

python () {
    if d.getVar('MACHINE') == 'mpxls1028crx07':
        d.setVar('PLATFORM', '${MACHINE}')
    elif d.getVar('MACHINE') == 'mpxlx2160acrx08':
        d.setVar('PLATFORM', '${MACHINE}')
    elif d.getVar('MACHINE') == 'mpxlx2160acrx08ai':
        d.setVar('PLATFORM', 'mpxlx2160acrx08')
    elif d.getVar('MACHINE') == 'mpxlx2160aacu':
        d.setVar('PLATFORM', 'mpxlx2160aacu')
    elif d.getVar('MACHINE').startswith('mpxls1088'):
        d.setVar('PLATFORM', 'mpxls1088a')
    elif d.getVar('MACHINE').startswith('mpxls1043'):
        d.setVar('PLATFORM', 'mpxls1043a')
    elif d.getVar('MACHINE').startswith('mpxls1046'):
        d.setVar('PLATFORM', 'mpxls1046a')
    else:
        d.setVar('PLATFORM', 'mpxls10xx')
}

ITS_DEVICETREE_CFG ?= "${ITS_DEVICETREE_CONFIG}"

do_install:append() {
    install -d ${DEPLOY_DIR_IMAGE}
    if [ -f "arch/${ARCH}/boot/Image" ]; then
        install -m 0644 arch/${ARCH}/boot/Image ${D}/boot/Image-${KERNEL_VERSION}
        ln -sf  Image-${KERNEL_VERSION} ${D}/boot/Image
    fi
    its_file=${S}/kernel-${PLATFORM}.its
    if [ ! -f ${its_file} ]; then
        its_file = ${S}/kernel-mpxls10xx.its
    fi
    default="            default = \"${ITS_DEVICETREE_CFG}\";"
    if [ -n "${ITS_DEVICETREE_CFG}" ]; then
        sed -e "s/^ *default *=.*$/${default}/g" ${its_file} > kernel-${PLATFORM}.its
    else
        cp ${its_file} kernel-${PLATFORM}.its
    fi
    mkimage -f kernel-${PLATFORM}.its fitImage.itb
    install -m 0644 fitImage.itb ${D}/boot/fitImage-${KERNEL_VERSION}.itb
    ln -sf fitImage-${KERNEL_VERSION}.itb ${D}/boot/fitImage.itb

    bbdebug 1 "Deploying fitImage-${KERNEL_VERSION}.itb\n"
    install -m 0644 ${D}/boot/fitImage-${KERNEL_VERSION}.itb ${DEPLOY_DIR_IMAGE}/fitImage-${KERNEL_VERSION}.itb
    ln -sf fitImage-${KERNEL_VERSION}.itb ${DEPLOY_DIR_IMAGE}/fitImage.itb
}

do_deploy:append() {
    install -d ${DEPLOY_DIR_IMAGE}
    bbdebug 1 "Deploying fitImage-${KERNEL_VERSION}.itb\n"
    install -m 0644 ${D}/boot/fitImage-${KERNEL_VERSION}.itb ${DEPLOY_DIR_IMAGE}/fitImage-${KERNEL_VERSION}.itb
    ln -sf fitImage-${KERNEL_VERSION}.itb ${DEPLOY_DIR_IMAGE}/fitImage.itb
}

FILES_${KERNEL_PACKAGE_NAME}-image += "/boot/Image*"
FILES_${KERNEL_PACKAGE_NAME}-image-fitimage += "/boot/fitImage*"

PACKAGES += "${PN}-images"
FILES:${PN}-images += "/boot"
COMPATIBLE_MACHINE = "(qoriq)"

FILES_${PN} += "/boot/fitImage*"

SRC_URI += "file://linux-qoriq.patch"
